Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5139)

Unified Diff: chrome/renderer/extensions/media_galleries_custom_bindings.h

Issue 10916019: Move MediaGalleries.getMediaFileSystems out of experimental. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update docs Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/extensions/media_galleries_custom_bindings.h
diff --git a/chrome/renderer/extensions/media_gallery_custom_bindings.h b/chrome/renderer/extensions/media_galleries_custom_bindings.h
similarity index 64%
rename from chrome/renderer/extensions/media_gallery_custom_bindings.h
rename to chrome/renderer/extensions/media_galleries_custom_bindings.h
index 14b3bec74f3ba042ff6893b3d68d374acea040a5..92bd4b92900d6f94b3bd0d2cf006f19d5c373f12 100644
--- a/chrome/renderer/extensions/media_gallery_custom_bindings.h
+++ b/chrome/renderer/extensions/media_galleries_custom_bindings.h
@@ -2,17 +2,17 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_RENDERER_EXTENSIONS_MEDIA_GALLERY_CUSTOM_BINDINGS_H_
-#define CHROME_RENDERER_EXTENSIONS_MEDIA_GALLERY_CUSTOM_BINDINGS_H_
+#ifndef CHROME_RENDERER_EXTENSIONS_MEDIA_GALLERIES_CUSTOM_BINDINGS_H_
+#define CHROME_RENDERER_EXTENSIONS_MEDIA_GALLERIES_CUSTOM_BINDINGS_H_
#include "chrome/renderer/extensions/chrome_v8_extension.h"
namespace extensions {
-// Implements custom bindings for the media gallery API.
-class MediaGalleryCustomBindings : public ChromeV8Extension {
+// Implements custom bindings for the media galleries API.
+class MediaGalleriesCustomBindings : public ChromeV8Extension {
public:
- MediaGalleryCustomBindings();
+ MediaGalleriesCustomBindings();
private:
// FileSystemObject GetMediaFileSystem(string file_system_url): construct
@@ -24,10 +24,10 @@ class MediaGalleryCustomBindings : public ChromeV8Extension {
// all of the thumbnails embedded in the passed file.
v8::Handle<v8::Value> ExtractEmbeddedThumbnails(const v8::Arguments& args);
- DISALLOW_COPY_AND_ASSIGN(MediaGalleryCustomBindings);
+ DISALLOW_COPY_AND_ASSIGN(MediaGalleriesCustomBindings);
};
} // extensions
-#endif // CHROME_RENDERER_EXTENSIONS_MEDIA_GALLERY_CUSTOM_BINDINGS_H_
+#endif // CHROME_RENDERER_EXTENSIONS_MEDIA_GALLERIES_CUSTOM_BINDINGS_H_

Powered by Google App Engine
This is Rietveld 408576698